@@ -98,6 +98,9 @@ PARSER.add_argument(
 PARSER.add_argument(
     '-p', '--presentational-hints', action='store_true',
     help='follow HTML presentational hints')
+PARSER.add_argument(
+    '--srgb', action='store_true',
+    help='include sRGB color profile')
 PARSER.add_argument(
     '--optimize-images', action='store_true',
     help='optimize size of embedded images with no quality loss')
@@ -137,7 +140,7 @@ PARSER.add_argument(
 PARSER.set_defaults(**DEFAULT_OPTIONS)
 
 
-def main(argv=None, stdout=None, stdin=None, HTML=HTML):
+def main(argv=None, stdout=None, stdin=None, HTML=HTML):  # noqa: N803
     """The ``weasyprint`` program takes at least two arguments:
 
     .. code-block:: sh
@@ -165,7 +168,8 @@ def main(argv=None, stdout=None, stdin=None, HTML=HTML):
     if args.timeout is not None:
         url_fetcher = partial(default_url_fetcher, timeout=args.timeout)
 
-    options = vars(args)
+    options = {
+        key: value for key, value in vars(args).items() if key in DEFAULT_OPTIONS}
 
     # Default to logging to stderr.
     if args.debug:
@@ -174,7 +178,14 @@ def main(argv=None, stdout=None, stdin=None, HTML=HTML):
         LOGGER.setLevel(logging.INFO)
     if not args.quiet:
         handler = logging.StreamHandler()
-        handler.setFormatter(logging.Formatter('%(levelname)s: %(message)s'))
+        if args.debug:
+            # Add extra information when debug logging
+            handler.setFormatter(
+                logging.Formatter(
+                    '%(levelname)s: %(filename)s:%(lineno)d '
+                    '(%(funcName)s): %(message)s'))
+        else:
+            handler.setFormatter(logging.Formatter('%(levelname)s: %(message)s'))
         LOGGER.addHandler(handler)
 
     html = HTML(
