@@ -127,8 +127,8 @@ class RasterImage:
             width, height = self.width, self.height
         else:
             thumbnail = Image.open(io.BytesIO(self.image_data.data))
-            width = max(1, int(round(self.width * dpi_ratio)))
-            height = max(1, int(round(self.height * dpi_ratio)))
+            width = max(1, round(self.width * dpi_ratio))
+            height = max(1, round(self.height * dpi_ratio))
             thumbnail.thumbnail((width, height))
             image_file = io.BytesIO()
             thumbnail.save(
@@ -486,7 +486,6 @@ class Gradient:
         return None, None, None
 
     def draw(self, stream, concrete_width, concrete_height, _image_rendering):
-        # TODO: handle color spaces
         scale_y, type_, points, positions, colors = self.layout(
             concrete_width, concrete_height)
 
@@ -500,8 +499,9 @@ class Gradient:
         alpha_couples = [
             (alphas[i], alphas[i + 1])
             for i in range(len(alphas) - 1)]
+        # TODO: handle other color spaces.
         color_couples = [
-            [colors[i][:3], colors[i + 1][:3], 1]
+            [colors[i].to('srgb')[:3], colors[i + 1].to('srgb')[:3], 1]
             for i in range(len(colors) - 1)]
 
         # Premultiply colors
@@ -525,6 +525,7 @@ class Gradient:
             for c0, c1, n in color_couples)
         function = stream.create_stitching_function(
             domain, encode, bounds, sub_functions)
+        # TODO: handle other color spaces.
         shading = stream.add_shading(
             shading_type, 'RGB', domain, points, extend, function)
         stream.transform(d=scale_y)
