@@ -103,7 +103,7 @@ class FontConfiguration:
         fontconfig.FcConfigDestroy(self._config)
 
         # Temporary folder storing fonts.
-        self._folder = Path(mkdtemp(prefix='weasyprint-'))
+        self._folder = None
 
     def add_font_face(self, rule_descriptors, url_fetcher):
         """Add a font face to the Fontconfig configuration."""
@@ -111,6 +111,8 @@ class FontConfiguration:
         # Define path where to save font, depending on the rule descriptors.
         config_key = str(rule_descriptors)
         config_digest = md5(config_key.encode(), usedforsecurity=False).hexdigest()
+        if self._folder is None:
+            self._folder = Path(mkdtemp(prefix='weasyprint-'))
         font_path = self._folder / config_digest
         if font_path.exists():
             # Font already exists, we have nothing more to do.
@@ -206,14 +208,23 @@ class FontConfiguration:
             match = SubElement(root, 'match', target='font')
             test = SubElement(match, 'test', name='file', compare='eq')
             SubElement(test, 'string').text = str(font_path)
-            edit = SubElement(match, 'edit', name='fontfeatures', mode=mode)
             descriptors = {
                 rules[0][0].replace('-', '_'): rules[0][1] for rules in
                 rule_descriptors.get('font_variant', [])}
             settings = rule_descriptors.get('font_feature_settings', 'normal')
             features = font_features(font_feature_settings=settings, **descriptors)
-            for key, value in features.items():
-                SubElement(edit, 'string').text = f'{key} {value}'
+            if features:
+                edit = SubElement(match, 'edit', name='fontfeatures', mode=mode)
+                for key, value in features.items():
+                    SubElement(edit, 'string').text = f'{key} {value}'
+            if unicode_ranges := rule_descriptors.get('unicode_range'):
+                edit = SubElement(match, 'edit', name='charset', mode=mode)
+                plus = SubElement(edit, 'plus')
+                for unicode_range in unicode_ranges:
+                    charset = SubElement(plus, 'charset')
+                    range_ = SubElement(charset, 'range')
+                    for value in (unicode_range.start, unicode_range.end):
+                        SubElement(range_, 'int').text = f'0x{value:x}'
             header = (
                 b'<?xml version="1.0"?>',
                 b'<!DOCTYPE fontconfig SYSTEM "urn:fontconfig:fonts.dtd">')
@@ -233,7 +244,8 @@ class FontConfiguration:
 
     def __del__(self):
         """Clean a font configuration for a document."""
-        rmtree(self._folder, ignore_errors=True)
+        if self._folder:
+            rmtree(self._folder, ignore_errors=True)
 
 
 def font_features(font_kerning='normal', font_variant_ligatures='normal',
